# Namespace for CreateProj
module CreateProj
  # Base class for CLI. Provides three project creation methods
  # dependent on language type.
  class CLI < Thor
    # @todo use metaprogramming to simplify this?

    desc 'haskell NAME', 'create a haskell project called NAME'
    # Command line input option for creating haskell project.
    #
    # @param [String] name the project
    #
    # @example Call from command line
    #   $ ./createproj haskell newproj #=> creates haskell proj called new proj
    #
    # @return Nothing
    def haskell(name)
      CreateProj::Creator::HaskellCreator.new(name, options).run
    end

    desc 'python NAME', 'create a python project called NAME'
    # Command line input option for creating python project.
    #
    # @param [String] name the project
    #
    # @example Call from command line
    #   $ ./createproj python newproj #=> creates python proj called newproj
    #
    # @return Nothing
    def python(name)
      CreateProj::Creator::PythonCreator.new(name, options).run
    end

    desc 'rails NAME', 'create a rails project called NAME'
    method_option :database, aliases: '-d', desc: 'database to use'
    method_option :javascript, aliases: '-j', desc: 'javascript library'
    method_option :skip_test_unit, aliases: '-T', desc: 'skip test unit'
    # Command line input option for creating rails project.
    #
    # @param [String] name the project
    #
    # @example Call from command line
    #   $ ./createproj haskell newproj #=> creates rails proj called new proj
    #
    # @return Nothing
    def rails(name)
      CreateProj::Creator::RailsCreator.new(name, options).run
    end

    desc 'ruby NAME', 'create a ruby project called NAME'
    # Command line input option for creating ruby project.
    #
    # @param [String] name the project
    #
    # @example Call from command line
    #   $ ./createproj ruby newproj #=> creates ruby proj called new proj
    #
    # @return Nothing
    def ruby(name)
      CreateProj::Creator::RubyCreator.new(name, options).run
    end
  end
end
