module CreateProj
  module Creator
    # Class for creating Haskell project
    class HaskellCreator < Creator
      def initialize(*args)
        super(*args)
        @precommit_template = 'lint-pre-commit'
        @precommit_options = { linter: 'hlint', file_ext: '.hs' }
        @gitignore_files = %w(cabal.sandbox.config .cabal-sandbox)
      end

      # Create an Haskell sandbox
      #
      # @example Create rvm sandbox for project named test
      #   install_sandbox #=> Executes `cabal sandbox init`
      #
      # @return Nothing
      def install_sandbox
        system('cabal sandbox init')
      end

      # Installs dependencies in the new cabal sandbox
      #
      # @example Installs rubocop in the gemset sandbox
      #   install_dependencies #=> happy & hlint installed in the gemset
      #
      # @return Nothing
      def install_dependencies
        cabals_to_install = %w(happy hlint)

        system('cabal update')

        cabals_to_install.each do |g|
          system("cabal install #{g}")
        end
      end
    end
  end
end
